@@ -193,10 +193,10 @@ def importGTF(**args):
                 if values["type"] == "stop_codon":
                     values["type"] = "exon"
                     values["frame"] = 3 - (values["hi"] - values["lo"])
-                    if values["strand"] == "-":
-                        values["lo"] = transcripts[values["transcriptId"]][values["chromosome"]]["lo"]
-                    else:
-                        values["hi"] = transcripts[values["transcriptId"]][values["chromosome"]]["hi"]
+                    #if values["strand"] == "-":
+                    #    values["lo"] = transcripts[values["transcriptId"]][values["chromosome"]]["lo"]
+                    #else:
+                    #    values["hi"] = transcripts[values["transcriptId"]][values["chromosome"]]["hi"]
                     
                 if values["type"] == "exon":
                     if (transcripts[values["transcriptId"]][values["chromosome"]]["codingLo"] != -1 and transcripts[values["transcriptId"]][values["chromosome"]]["codingHi"] != -1):
@@ -283,10 +283,8 @@ def parseLine(line, capturedTypes):
     chromosome = tabSplit[0]
     source = tabSplit[1]
     typ = tabSplit[2]
-    if capturedTypes.get(typ) == None == None:
-        message = 'Permitted types:'
-        for k, v in capturedTypes.iteritems():
-            message += " " + k + ","
+    if capturedTypes.get(typ) == None:
+        message = 'Permitted types: ' + " ,".join(capturedTypes.keys())
         raise dxpy.AppError("One row had a type which is not in the list of permitted types. " + message + "\nOffending line: " + line + "\nOffending type: " + typ)
 
     try:
@@ -407,8 +405,13 @@ def constructTable(inputFileName):
             schema.append({"name": k, "type": "string"})
             additionalColumns.append(k)
 
-    indices = [dxpy.DXGTable.genomic_range_index("chr","lo","hi", 'gri'), dxpy.DXGTable.lexicographic_index([["name", "ASC"]], "search")]
-    #indices = [dxpy.DXGTable.genomic_range_index("chr","lo","hi", 'gri')]
+    indices = [dxpy.DXGTable.genomic_range_index("chr","lo","hi", 'gri'), 
+               dxpy.DXGTable.lexicographic_index([
+                  dxpy.DXGTable.lexicographic_index_column("name", True, False),
+                  dxpy.DXGTable.lexicographic_index_column("chr"),
+                  dxpy.DXGTable.lexicographic_index_column("lo"),
+                  dxpy.DXGTable.lexicographic_index_column("hi"),
+                  dxpy.DXGTable.lexicographic_index_column("type")], "search")]
     spansTable = dxpy.new_dxgtable(columns=schema, indices=indices)
     return spansTable, additionalColumns
 
