@@ -18,13 +18,14 @@
 #   under the License.
 
 import os, sys, unittest, json, tempfile, subprocess, csv, shutil, re
-
 import pexpect
 
+from . import DXTestCase
+
 import dxpy
 from dxpy.scripts import dx_build_app
 
-class TestDXAppWizardAndRunAppLocally(unittest.TestCase):
+class TestDXAppWizardAndRunAppLocally(DXTestCase):
     def test_dx_app_wizard(self):
         tempdir = tempfile.mkdtemp()
         os.chdir(tempdir)
@@ -92,8 +93,13 @@ class TestDXAppWizardAndRunAppLocally(unittest.TestCase):
         self.assertIn("Final output: out1 = 140", output)
         return appdir
 
+    @unittest.skipIf('DXTEST_RUN_JOBS' not in os.environ,
+                     'skipping test that would run jobs')
     def test_dx_run_app_locally_and_compare_results(self):
         appdir = self.test_dx_run_app_locally()
+        print "Setting current project to", self.project
+        dxpy.WORKSPACE_ID = self.project
+        dxpy.PROJECT_CONTEXT_ID = self.project
         applet_id = dx_build_app.build_and_upload_locally(appdir,
                                                           mode='applet',
                                                           overwrite=True,
